Class: DnaPaymentsPartnerReportingSettlementApIs::PosTransactionsResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/dna_payments_partner_reporting_settlement_ap_is/models/pos_transactions_response.rb

Overview

PosTransactionsResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(total_amount: SKIP, total_count: SKIP, data: SKIP, additional_properties: nil) ⇒ PosTransactionsResponse

Returns a new instance of PosTransactionsResponse.



47
48
49
50
51
52
53
54
55
56
# File 'lib/dna_payments_partner_reporting_settlement_ap_is/models/pos_transactions_response.rb', line 47

def initialize(total_amount: SKIP, total_count: SKIP, data: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @total_amount = total_amount unless total_amount == SKIP
  @total_count = total_count unless total_count == SKIP
  @data = data unless data == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#dataArray[PosTransaction]

Total count of records for the requested time period.

Returns:



22
23
24
# File 'lib/dna_payments_partner_reporting_settlement_ap_is/models/pos_transactions_response.rb', line 22

def data
  @data
end

#total_amountFloat

Total amount for the requested time period.

Returns:

  • (Float)


14
15
16
# File 'lib/dna_payments_partner_reporting_settlement_ap_is/models/pos_transactions_response.rb', line 14

def total_amount
  @total_amount
end

#total_countInteger

Total count of records for the requested time period.

Returns:

  • (Integer)


18
19
20
# File 'lib/dna_payments_partner_reporting_settlement_ap_is/models/pos_transactions_response.rb', line 18

def total_count
  @total_count
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/dna_payments_partner_reporting_settlement_ap_is/models/pos_transactions_response.rb', line 59

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  total_amount = hash.key?('totalAmount') ? hash['totalAmount'] : SKIP
  total_count = hash.key?('totalCount') ? hash['totalCount'] : SKIP
  # Parameter is an array, so we need to iterate through it
  data = nil
  unless hash['data'].nil?
    data = []
    hash['data'].each do |structure|
      data << (PosTransaction.from_hash(structure) if structure)
    end
  end

  data = SKIP unless hash.key?('data')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  PosTransactionsResponse.new(total_amount: total_amount,
                              total_count: total_count,
                              data: data,
                              additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/dna_payments_partner_reporting_settlement_ap_is/models/pos_transactions_response.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['total_amount'] = 'totalAmount'
  @_hash['total_count'] = 'totalCount'
  @_hash['data'] = 'data'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/dna_payments_partner_reporting_settlement_ap_is/models/pos_transactions_response.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/dna_payments_partner_reporting_settlement_ap_is/models/pos_transactions_response.rb', line 34

def self.optionals
  %w[
    total_amount
    total_count
    data
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



98
99
100
101
102
103
# File 'lib/dna_payments_partner_reporting_settlement_ap_is/models/pos_transactions_response.rb', line 98

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} total_amount: #{@total_amount.inspect}, total_count:"\
  " #{@total_count.inspect}, data: #{@data.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



91
92
93
94
95
# File 'lib/dna_payments_partner_reporting_settlement_ap_is/models/pos_transactions_response.rb', line 91

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} total_amount: #{@total_amount}, total_count: #{@total_count}, data:"\
  " #{@data}, additional_properties: #{@additional_properties}>"
end