Class: DnaPaymentsPartnerReportingSettlementApIs::SettlementsResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/dna_payments_partner_reporting_settlement_ap_is/models/settlements_response.rb

Overview

SettlementsResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(total_count: SKIP, data: SKIP, additional_properties: nil) ⇒ SettlementsResponse

Returns a new instance of SettlementsResponse.



41
42
43
44
45
46
47
48
# File 'lib/dna_payments_partner_reporting_settlement_ap_is/models/settlements_response.rb', line 41

def initialize(total_count: SKIP, data: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @total_count = total_count unless total_count == SKIP
  @data = data unless data == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#dataArray[Settlement]

Total count of records for the requested time period.

Returns:



18
19
20
# File 'lib/dna_payments_partner_reporting_settlement_ap_is/models/settlements_response.rb', line 18

def data
  @data
end

#total_countInteger

Total count of records for the requested time period.

Returns:

  • (Integer)


14
15
16
# File 'lib/dna_payments_partner_reporting_settlement_ap_is/models/settlements_response.rb', line 14

def total_count
  @total_count
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/dna_payments_partner_reporting_settlement_ap_is/models/settlements_response.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  total_count = hash.key?('totalCount') ? hash['totalCount'] : SKIP
  # Parameter is an array, so we need to iterate through it
  data = nil
  unless hash['data'].nil?
    data = []
    hash['data'].each do |structure|
      data << (Settlement.from_hash(structure) if structure)
    end
  end

  data = SKIP unless hash.key?('data')

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  SettlementsResponse.new(total_count: total_count,
                          data: data,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/dna_payments_partner_reporting_settlement_ap_is/models/settlements_response.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['total_count'] = 'totalCount'
  @_hash['data'] = 'data'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/dna_payments_partner_reporting_settlement_ap_is/models/settlements_response.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/dna_payments_partner_reporting_settlement_ap_is/models/settlements_response.rb', line 29

def self.optionals
  %w[
    total_count
    data
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



88
89
90
91
92
# File 'lib/dna_payments_partner_reporting_settlement_ap_is/models/settlements_response.rb', line 88

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} total_count: #{@total_count.inspect}, data: #{@data.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



81
82
83
84
85
# File 'lib/dna_payments_partner_reporting_settlement_ap_is/models/settlements_response.rb', line 81

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} total_count: #{@total_count}, data: #{@data}, additional_properties:"\
  " #{@additional_properties}>"
end